// Copyright (c) 2023 Tudor Stanciu

import React, { useReducer, useMemo, ReactNode } from "react";
import { TuitioContext, TuitioDispatchContext } from "./contexts";
import { initialState } from "./initialState";
import { reducer, dispatchActions } from "./reducer";
import { TuitioReactState } from "./types";

type Props = {
  children: ReactNode;
  tuitioUrl: string;
};

const TuitioProvider = ({ children, tuitioUrl }: Props) => {
  const initState: TuitioReactState = { ...initialState, configuration: { tuitioUrl } };
  const [state, dispatch] = useReducer(reducer, initState);
  const actions = useMemo(() => dispatchActions(dispatch), [dispatch]);

  return (
    <TuitioContext.Provider value={state}>
      <TuitioDispatchContext.Provider value={actions}>{children}</TuitioDispatchContext.Provider>
    </TuitioContext.Provider>
  );
};

export default TuitioProvider;
