// Copyright (c) 2023 Tudor Stanciu

import { useContext, useCallback } from "react";
import { TuitioContext } from "../contexts";

const useTuitioToken = () => {
  const state = useContext(TuitioContext);
  const token = state.auth.token;

  const validate = useCallback((): boolean => {
    const validUntil = state.auth.validUntil;
    if (!validUntil) {
      return false;
    }
    const valid = new Date(validUntil) >= new Date();
    return valid;
  }, [state.auth.validUntil]);

  const valid: boolean = validate();

  return { token, validate, valid };
};

export { useTuitioToken };
